@@ -4,7 +4,10 @@
 import pandas as pd
 import numpy as np
 
-df = pd.read_csv('src/data/Final_Project_Raw_Data.csv')
+def load_data():
+    df = pd.read_csv('src/data/Final_Project_Raw_Data.csv')
+
+    return df
 
 def count_ripper(data_frame, column_name, brewery_name):
     individual_brewery = data_frame.loc[(data_frame[column_name] == brewery_name)]
@@ -51,11 +54,11 @@ def brewery_with_dates(df, column_name_1, column_name_2, column_name_3, brewery_
 
   return single_brewery_from_frame_reduced
 
-breweries_only = df.dropna(subset=['location_name'])
+#breweries_only = df.dropna(subset=['location_name'])
 
-breweries_only = breweries_only[(breweries_only.location_name != 'Artisanal Brewing Ventures') & (breweries_only.location_name != 'Optimist Hall') &
-                                (breweries_only.location_name != 'Red Clay Cider Works') & (breweries_only.location_name != 'Adams Beverages of North Carolina') &
-                                (breweries_only.location_name != 'Kind Beer Distributing')& (breweries_only.location_name != 'GoodRoad CiderWorks') &
-                                (breweries_only.location_name != 'Deutsche Beverage Technology') & (breweries_only.location_name != 'Seven Jars Products') &
-                                (breweries_only.location_name != "OMB Captain Jack's Tavern") & (breweries_only.location_name != 'The Chamber By Wooden Robot') &
-                                (breweries_only.location_name != 'The Chamber Wooden Robot')]
+#breweries_only = breweries_only[(breweries_only.location_name != 'Artisanal Brewing Ventures') & (breweries_only.location_name != 'Optimist Hall') &
+                              #  (breweries_only.location_name != 'Red Clay Cider Works') & (breweries_only.location_name != 'Adams Beverages of North Carolina') &
+                               # (breweries_only.location_name != 'Kind Beer Distributing')& (breweries_only.location_name != 'GoodRoad CiderWorks') &
+                               # (breweries_only.location_name != 'Deutsche Beverage Technology') & (breweries_only.location_name != 'Seven Jars Products') &
+                              #  (breweries_only.location_name != "OMB Captain Jack's Tavern") & (breweries_only.location_name != 'The Chamber By Wooden Robot') &
+                              #  (breweries_only.location_name != 'The Chamber Wooden Robot')]
